@@ -4,7 +4,6 @@ from __future__ import unicode_literals
 from django.db import migrations, models
 import organizations.fields
 
-
 class Migration(migrations.Migration):
 
     dependencies = [
@@ -15,6 +14,6 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='organization',
             name='slug',
-            field=organizations.fields.SlugField(help_text='The name in all lowercase, suitable for URL identification', unique=True, populate_from='name', max_length=200, editable=True),
+            field=organizations.fields.SlugField(blank=True, editable=False, help_text='The name in all lowercase, suitable for URL identification', max_length=200, populate_from=('name',), unique=True),
         ),
     ]
